# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/plugins/kubeflow/mpi.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.core import tasks_pb2 as flyteidl_dot_core_dot_tasks__pb2
from flyteidl.plugins.kubeflow import common_pb2 as flyteidl_dot_plugins_dot_kubeflow_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/plugins/kubeflow/mpi.proto',
  package='flyteidl.plugins.kubeflow',
  syntax='proto3',
  serialized_options=_b('Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/plugins'),
  serialized_pb=_b('\n#flyteidl/plugins/kubeflow/mpi.proto\x12\x19\x66lyteidl.plugins.kubeflow\x1a\x19\x66lyteidl/core/tasks.proto\x1a&flyteidl/plugins/kubeflow/common.proto\"\x95\x02\n\x1a\x44istributedMPITrainingTask\x12U\n\x0fworker_replicas\x18\x01 \x01(\x0b\x32<.flyteidl.plugins.kubeflow.DistributedMPITrainingReplicaSpec\x12W\n\x11launcher_replicas\x18\x02 \x01(\x0b\x32<.flyteidl.plugins.kubeflow.DistributedMPITrainingReplicaSpec\x12\x38\n\nrun_policy\x18\x03 \x01(\x0b\x32$.flyteidl.plugins.kubeflow.RunPolicy\x12\r\n\x05slots\x18\x04 \x01(\x05\"\xc4\x01\n!DistributedMPITrainingReplicaSpec\x12\x10\n\x08replicas\x18\x01 \x01(\x05\x12\r\n\x05image\x18\x02 \x01(\t\x12+\n\tresources\x18\x03 \x01(\x0b\x32\x18.flyteidl.core.Resources\x12@\n\x0erestart_policy\x18\x04 \x01(\x0e\x32(.flyteidl.plugins.kubeflow.RestartPolicy\x12\x0f\n\x07\x63ommand\x18\x05 \x03(\tB9Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/pluginsb\x06proto3')
  ,
  dependencies=[flyteidl_dot_core_dot_tasks__pb2.DESCRIPTOR,flyteidl_dot_plugins_dot_kubeflow_dot_common__pb2.DESCRIPTOR,])




_DISTRIBUTEDMPITRAININGTASK = _descriptor.Descriptor(
  name='DistributedMPITrainingTask',
  full_name='flyteidl.plugins.kubeflow.DistributedMPITrainingTask',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='worker_replicas', full_name='flyteidl.plugins.kubeflow.DistributedMPITrainingTask.worker_replicas', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='launcher_replicas', full_name='flyteidl.plugins.kubeflow.DistributedMPITrainingTask.launcher_replicas', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='run_policy', full_name='flyteidl.plugins.kubeflow.DistributedMPITrainingTask.run_policy', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slots', full_name='flyteidl.plugins.kubeflow.DistributedMPITrainingTask.slots', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134,
  serialized_end=411,
)


_DISTRIBUTEDMPITRAININGREPLICASPEC = _descriptor.Descriptor(
  name='DistributedMPITrainingReplicaSpec',
  full_name='flyteidl.plugins.kubeflow.DistributedMPITrainingReplicaSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='replicas', full_name='flyteidl.plugins.kubeflow.DistributedMPITrainingReplicaSpec.replicas', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image', full_name='flyteidl.plugins.kubeflow.DistributedMPITrainingReplicaSpec.image', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resources', full_name='flyteidl.plugins.kubeflow.DistributedMPITrainingReplicaSpec.resources', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='restart_policy', full_name='flyteidl.plugins.kubeflow.DistributedMPITrainingReplicaSpec.restart_policy', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='command', full_name='flyteidl.plugins.kubeflow.DistributedMPITrainingReplicaSpec.command', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=414,
  serialized_end=610,
)

_DISTRIBUTEDMPITRAININGTASK.fields_by_name['worker_replicas'].message_type = _DISTRIBUTEDMPITRAININGREPLICASPEC
_DISTRIBUTEDMPITRAININGTASK.fields_by_name['launcher_replicas'].message_type = _DISTRIBUTEDMPITRAININGREPLICASPEC
_DISTRIBUTEDMPITRAININGTASK.fields_by_name['run_policy'].message_type = flyteidl_dot_plugins_dot_kubeflow_dot_common__pb2._RUNPOLICY
_DISTRIBUTEDMPITRAININGREPLICASPEC.fields_by_name['resources'].message_type = flyteidl_dot_core_dot_tasks__pb2._RESOURCES
_DISTRIBUTEDMPITRAININGREPLICASPEC.fields_by_name['restart_policy'].enum_type = flyteidl_dot_plugins_dot_kubeflow_dot_common__pb2._RESTARTPOLICY
DESCRIPTOR.message_types_by_name['DistributedMPITrainingTask'] = _DISTRIBUTEDMPITRAININGTASK
DESCRIPTOR.message_types_by_name['DistributedMPITrainingReplicaSpec'] = _DISTRIBUTEDMPITRAININGREPLICASPEC
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DistributedMPITrainingTask = _reflection.GeneratedProtocolMessageType('DistributedMPITrainingTask', (_message.Message,), dict(
  DESCRIPTOR = _DISTRIBUTEDMPITRAININGTASK,
  __module__ = 'flyteidl.plugins.kubeflow.mpi_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.kubeflow.DistributedMPITrainingTask)
  ))
_sym_db.RegisterMessage(DistributedMPITrainingTask)

DistributedMPITrainingReplicaSpec = _reflection.GeneratedProtocolMessageType('DistributedMPITrainingReplicaSpec', (_message.Message,), dict(
  DESCRIPTOR = _DISTRIBUTEDMPITRAININGREPLICASPEC,
  __module__ = 'flyteidl.plugins.kubeflow.mpi_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.kubeflow.DistributedMPITrainingReplicaSpec)
  ))
_sym_db.RegisterMessage(DistributedMPITrainingReplicaSpec)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/service/external_plugin_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.core import literals_pb2 as flyteidl_dot_core_dot_literals__pb2
from flyteidl.core import tasks_pb2 as flyteidl_dot_core_dot_tasks__pb2
from flyteidl.core import interface_pb2 as flyteidl_dot_core_dot_interface__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/service/external_plugin_service.proto',
  package='flyteidl.service',
  syntax='proto3',
  serialized_options=_b('Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/service'),
  serialized_pb=_b('\n.flyteidl/service/external_plugin_service.proto\x12\x10\x66lyteidl.service\x1a\x1c\x66lyteidl/core/literals.proto\x1a\x19\x66lyteidl/core/tasks.proto\x1a\x1d\x66lyteidl/core/interface.proto\"\x84\x01\n\x11TaskCreateRequest\x12)\n\x06inputs\x18\x01 \x01(\x0b\x32\x19.flyteidl.core.LiteralMap\x12-\n\x08template\x18\x02 \x01(\x0b\x32\x1b.flyteidl.core.TaskTemplate\x12\x15\n\routput_prefix\x18\x03 \x01(\t\"$\n\x12TaskCreateResponse\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"3\n\x0eTaskGetRequest\x12\x11\n\ttask_type\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\t\"e\n\x0fTaskGetResponse\x12&\n\x05state\x18\x01 \x01(\x0e\x32\x17.flyteidl.service.State\x12*\n\x07outputs\x18\x02 \x01(\x0b\x32\x19.flyteidl.core.LiteralMap\"6\n\x11TaskDeleteRequest\x12\x11\n\ttask_type\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\t\"\x14\n\x12TaskDeleteResponse*^\n\x05State\x12\x15\n\x11RETRYABLE_FAILURE\x10\x00\x12\x15\n\x11PERMANENT_FAILURE\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\x0b\n\x07RUNNING\x10\x03\x12\r\n\tSUCCEEDED\x10\x04\x32\x9f\x02\n\x15\x45xternalPluginService\x12Y\n\nCreateTask\x12#.flyteidl.service.TaskCreateRequest\x1a$.flyteidl.service.TaskCreateResponse\"\x00\x12P\n\x07GetTask\x12 .flyteidl.service.TaskGetRequest\x1a!.flyteidl.service.TaskGetResponse\"\x00\x12Y\n\nDeleteTask\x12#.flyteidl.service.TaskDeleteRequest\x1a$.flyteidl.service.TaskDeleteResponse\"\x00\x42\x39Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/serviceb\x06proto3')
  ,
  dependencies=[flyteidl_dot_core_dot_literals__pb2.DESCRIPTOR,flyteidl_dot_core_dot_tasks__pb2.DESCRIPTOR,flyteidl_dot_core_dot_interface__pb2.DESCRIPTOR,])

_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='flyteidl.service.State',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RETRYABLE_FAILURE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PERMANENT_FAILURE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUCCEEDED', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=563,
  serialized_end=657,
)
_sym_db.RegisterEnumDescriptor(_STATE)

State = enum_type_wrapper.EnumTypeWrapper(_STATE)
RETRYABLE_FAILURE = 0
PERMANENT_FAILURE = 1
PENDING = 2
RUNNING = 3
SUCCEEDED = 4



_TASKCREATEREQUEST = _descriptor.Descriptor(
  name='TaskCreateRequest',
  full_name='flyteidl.service.TaskCreateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='inputs', full_name='flyteidl.service.TaskCreateRequest.inputs', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='template', full_name='flyteidl.service.TaskCreateRequest.template', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_prefix', full_name='flyteidl.service.TaskCreateRequest.output_prefix', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=157,
  serialized_end=289,
)


_TASKCREATERESPONSE = _descriptor.Descriptor(
  name='TaskCreateResponse',
  full_name='flyteidl.service.TaskCreateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_id', full_name='flyteidl.service.TaskCreateResponse.job_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=291,
  serialized_end=327,
)


_TASKGETREQUEST = _descriptor.Descriptor(
  name='TaskGetRequest',
  full_name='flyteidl.service.TaskGetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_type', full_name='flyteidl.service.TaskGetRequest.task_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job_id', full_name='flyteidl.service.TaskGetRequest.job_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=329,
  serialized_end=380,
)


_TASKGETRESPONSE = _descriptor.Descriptor(
  name='TaskGetResponse',
  full_name='flyteidl.service.TaskGetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='flyteidl.service.TaskGetResponse.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outputs', full_name='flyteidl.service.TaskGetResponse.outputs', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=382,
  serialized_end=483,
)


_TASKDELETEREQUEST = _descriptor.Descriptor(
  name='TaskDeleteRequest',
  full_name='flyteidl.service.TaskDeleteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_type', full_name='flyteidl.service.TaskDeleteRequest.task_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job_id', full_name='flyteidl.service.TaskDeleteRequest.job_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=485,
  serialized_end=539,
)


_TASKDELETERESPONSE = _descriptor.Descriptor(
  name='TaskDeleteResponse',
  full_name='flyteidl.service.TaskDeleteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=541,
  serialized_end=561,
)

_TASKCREATEREQUEST.fields_by_name['inputs'].message_type = flyteidl_dot_core_dot_literals__pb2._LITERALMAP
_TASKCREATEREQUEST.fields_by_name['template'].message_type = flyteidl_dot_core_dot_tasks__pb2._TASKTEMPLATE
_TASKGETRESPONSE.fields_by_name['state'].enum_type = _STATE
_TASKGETRESPONSE.fields_by_name['outputs'].message_type = flyteidl_dot_core_dot_literals__pb2._LITERALMAP
DESCRIPTOR.message_types_by_name['TaskCreateRequest'] = _TASKCREATEREQUEST
DESCRIPTOR.message_types_by_name['TaskCreateResponse'] = _TASKCREATERESPONSE
DESCRIPTOR.message_types_by_name['TaskGetRequest'] = _TASKGETREQUEST
DESCRIPTOR.message_types_by_name['TaskGetResponse'] = _TASKGETRESPONSE
DESCRIPTOR.message_types_by_name['TaskDeleteRequest'] = _TASKDELETEREQUEST
DESCRIPTOR.message_types_by_name['TaskDeleteResponse'] = _TASKDELETERESPONSE
DESCRIPTOR.enum_types_by_name['State'] = _STATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TaskCreateRequest = _reflection.GeneratedProtocolMessageType('TaskCreateRequest', (_message.Message,), dict(
  DESCRIPTOR = _TASKCREATEREQUEST,
  __module__ = 'flyteidl.service.external_plugin_service_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.service.TaskCreateRequest)
  ))
_sym_db.RegisterMessage(TaskCreateRequest)

TaskCreateResponse = _reflection.GeneratedProtocolMessageType('TaskCreateResponse', (_message.Message,), dict(
  DESCRIPTOR = _TASKCREATERESPONSE,
  __module__ = 'flyteidl.service.external_plugin_service_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.service.TaskCreateResponse)
  ))
_sym_db.RegisterMessage(TaskCreateResponse)

TaskGetRequest = _reflection.GeneratedProtocolMessageType('TaskGetRequest', (_message.Message,), dict(
  DESCRIPTOR = _TASKGETREQUEST,
  __module__ = 'flyteidl.service.external_plugin_service_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.service.TaskGetRequest)
  ))
_sym_db.RegisterMessage(TaskGetRequest)

TaskGetResponse = _reflection.GeneratedProtocolMessageType('TaskGetResponse', (_message.Message,), dict(
  DESCRIPTOR = _TASKGETRESPONSE,
  __module__ = 'flyteidl.service.external_plugin_service_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.service.TaskGetResponse)
  ))
_sym_db.RegisterMessage(TaskGetResponse)

TaskDeleteRequest = _reflection.GeneratedProtocolMessageType('TaskDeleteRequest', (_message.Message,), dict(
  DESCRIPTOR = _TASKDELETEREQUEST,
  __module__ = 'flyteidl.service.external_plugin_service_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.service.TaskDeleteRequest)
  ))
_sym_db.RegisterMessage(TaskDeleteRequest)

TaskDeleteResponse = _reflection.GeneratedProtocolMessageType('TaskDeleteResponse', (_message.Message,), dict(
  DESCRIPTOR = _TASKDELETERESPONSE,
  __module__ = 'flyteidl.service.external_plugin_service_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.service.TaskDeleteResponse)
  ))
_sym_db.RegisterMessage(TaskDeleteResponse)


DESCRIPTOR._options = None

_EXTERNALPLUGINSERVICE = _descriptor.ServiceDescriptor(
  name='ExternalPluginService',
  full_name='flyteidl.service.ExternalPluginService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=660,
  serialized_end=947,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateTask',
    full_name='flyteidl.service.ExternalPluginService.CreateTask',
    index=0,
    containing_service=None,
    input_type=_TASKCREATEREQUEST,
    output_type=_TASKCREATERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetTask',
    full_name='flyteidl.service.ExternalPluginService.GetTask',
    index=1,
    containing_service=None,
    input_type=_TASKGETREQUEST,
    output_type=_TASKGETRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteTask',
    full_name='flyteidl.service.ExternalPluginService.DeleteTask',
    index=2,
    containing_service=None,
    input_type=_TASKDELETEREQUEST,
    output_type=_TASKDELETERESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_EXTERNALPLUGINSERVICE)

DESCRIPTOR.services_by_name['ExternalPluginService'] = _EXTERNALPLUGINSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/core/metrics.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.core import identifier_pb2 as flyteidl_dot_core_dot_identifier__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/core/metrics.proto',
  package='flyteidl.core',
  syntax='proto3',
  serialized_options=_b('Z4github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/core'),
  serialized_pb=_b('\n\x1b\x66lyteidl/core/metrics.proto\x12\rflyteidl.core\x1a\x1e\x66lyteidl/core/identifier.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xdf\x02\n\x04Span\x12.\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x41\n\x0bworkflow_id\x18\x03 \x01(\x0b\x32*.flyteidl.core.WorkflowExecutionIdentifierH\x00\x12\x39\n\x07node_id\x18\x04 \x01(\x0b\x32&.flyteidl.core.NodeExecutionIdentifierH\x00\x12\x39\n\x07task_id\x18\x05 \x01(\x0b\x32&.flyteidl.core.TaskExecutionIdentifierH\x00\x12\x16\n\x0coperation_id\x18\x06 \x01(\tH\x00\x12\"\n\x05spans\x18\x07 \x03(\x0b\x32\x13.flyteidl.core.SpanB\x04\n\x02idB6Z4github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/coreb\x06proto3')
  ,
  dependencies=[flyteidl_dot_core_dot_identifier__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_SPAN = _descriptor.Descriptor(
  name='Span',
  full_name='flyteidl.core.Span',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_time', full_name='flyteidl.core.Span.start_time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='flyteidl.core.Span.end_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='workflow_id', full_name='flyteidl.core.Span.workflow_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node_id', full_name='flyteidl.core.Span.node_id', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='task_id', full_name='flyteidl.core.Span.task_id', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operation_id', full_name='flyteidl.core.Span.operation_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spans', full_name='flyteidl.core.Span.spans', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='id', full_name='flyteidl.core.Span.id',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=112,
  serialized_end=463,
)

_SPAN.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SPAN.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SPAN.fields_by_name['workflow_id'].message_type = flyteidl_dot_core_dot_identifier__pb2._WORKFLOWEXECUTIONIDENTIFIER
_SPAN.fields_by_name['node_id'].message_type = flyteidl_dot_core_dot_identifier__pb2._NODEEXECUTIONIDENTIFIER
_SPAN.fields_by_name['task_id'].message_type = flyteidl_dot_core_dot_identifier__pb2._TASKEXECUTIONIDENTIFIER
_SPAN.fields_by_name['spans'].message_type = _SPAN
_SPAN.oneofs_by_name['id'].fields.append(
  _SPAN.fields_by_name['workflow_id'])
_SPAN.fields_by_name['workflow_id'].containing_oneof = _SPAN.oneofs_by_name['id']
_SPAN.oneofs_by_name['id'].fields.append(
  _SPAN.fields_by_name['node_id'])
_SPAN.fields_by_name['node_id'].containing_oneof = _SPAN.oneofs_by_name['id']
_SPAN.oneofs_by_name['id'].fields.append(
  _SPAN.fields_by_name['task_id'])
_SPAN.fields_by_name['task_id'].containing_oneof = _SPAN.oneofs_by_name['id']
_SPAN.oneofs_by_name['id'].fields.append(
  _SPAN.fields_by_name['operation_id'])
_SPAN.fields_by_name['operation_id'].containing_oneof = _SPAN.oneofs_by_name['id']
DESCRIPTOR.message_types_by_name['Span'] = _SPAN
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Span = _reflection.GeneratedProtocolMessageType('Span', (_message.Message,), dict(
  DESCRIPTOR = _SPAN,
  __module__ = 'flyteidl.core.metrics_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.core.Span)
  ))
_sym_db.RegisterMessage(Span)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/admin/signal.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.admin import common_pb2 as flyteidl_dot_admin_dot_common__pb2
from flyteidl.core import identifier_pb2 as flyteidl_dot_core_dot_identifier__pb2
from flyteidl.core import literals_pb2 as flyteidl_dot_core_dot_literals__pb2
from flyteidl.core import types_pb2 as flyteidl_dot_core_dot_types__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/admin/signal.proto',
  package='flyteidl.admin',
  syntax='proto3',
  serialized_options=_b('Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/admin'),
  serialized_pb=_b('\n\x1b\x66lyteidl/admin/signal.proto\x12\x0e\x66lyteidl.admin\x1a\x1b\x66lyteidl/admin/common.proto\x1a\x1e\x66lyteidl/core/identifier.proto\x1a\x1c\x66lyteidl/core/literals.proto\x1a\x19\x66lyteidl/core/types.proto\"q\n\x18SignalGetOrCreateRequest\x12+\n\x02id\x18\x01 \x01(\x0b\x32\x1f.flyteidl.core.SignalIdentifier\x12(\n\x04type\x18\x02 \x01(\x0b\x32\x1a.flyteidl.core.LiteralType\"\xb4\x01\n\x11SignalListRequest\x12I\n\x15workflow_execution_id\x18\x01 \x01(\x0b\x32*.flyteidl.core.WorkflowExecutionIdentifier\x12\r\n\x05limit\x18\x02 \x01(\r\x12\r\n\x05token\x18\x03 \x01(\t\x12\x0f\n\x07\x66ilters\x18\x04 \x01(\t\x12%\n\x07sort_by\x18\x05 \x01(\x0b\x32\x14.flyteidl.admin.Sort\"D\n\nSignalList\x12\'\n\x07signals\x18\x01 \x03(\x0b\x32\x16.flyteidl.admin.Signal\x12\r\n\x05token\x18\x02 \x01(\t\"f\n\x10SignalSetRequest\x12+\n\x02id\x18\x01 \x01(\x0b\x32\x1f.flyteidl.core.SignalIdentifier\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.flyteidl.core.Literal\"\x13\n\x11SignalSetResponse\"\x86\x01\n\x06Signal\x12+\n\x02id\x18\x01 \x01(\x0b\x32\x1f.flyteidl.core.SignalIdentifier\x12(\n\x04type\x18\x02 \x01(\x0b\x32\x1a.flyteidl.core.LiteralType\x12%\n\x05value\x18\x03 \x01(\x0b\x32\x16.flyteidl.core.LiteralB7Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/adminb\x06proto3')
  ,
  dependencies=[flyteidl_dot_admin_dot_common__pb2.DESCRIPTOR,flyteidl_dot_core_dot_identifier__pb2.DESCRIPTOR,flyteidl_dot_core_dot_literals__pb2.DESCRIPTOR,flyteidl_dot_core_dot_types__pb2.DESCRIPTOR,])




_SIGNALGETORCREATEREQUEST = _descriptor.Descriptor(
  name='SignalGetOrCreateRequest',
  full_name='flyteidl.admin.SignalGetOrCreateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.admin.SignalGetOrCreateRequest.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='flyteidl.admin.SignalGetOrCreateRequest.type', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=165,
  serialized_end=278,
)


_SIGNALLISTREQUEST = _descriptor.Descriptor(
  name='SignalListRequest',
  full_name='flyteidl.admin.SignalListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='workflow_execution_id', full_name='flyteidl.admin.SignalListRequest.workflow_execution_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='flyteidl.admin.SignalListRequest.limit', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token', full_name='flyteidl.admin.SignalListRequest.token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filters', full_name='flyteidl.admin.SignalListRequest.filters', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sort_by', full_name='flyteidl.admin.SignalListRequest.sort_by', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=281,
  serialized_end=461,
)


_SIGNALLIST = _descriptor.Descriptor(
  name='SignalList',
  full_name='flyteidl.admin.SignalList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signals', full_name='flyteidl.admin.SignalList.signals', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token', full_name='flyteidl.admin.SignalList.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=463,
  serialized_end=531,
)


_SIGNALSETREQUEST = _descriptor.Descriptor(
  name='SignalSetRequest',
  full_name='flyteidl.admin.SignalSetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.admin.SignalSetRequest.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='flyteidl.admin.SignalSetRequest.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=533,
  serialized_end=635,
)


_SIGNALSETRESPONSE = _descriptor.Descriptor(
  name='SignalSetResponse',
  full_name='flyteidl.admin.SignalSetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=637,
  serialized_end=656,
)


_SIGNAL = _descriptor.Descriptor(
  name='Signal',
  full_name='flyteidl.admin.Signal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.admin.Signal.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='flyteidl.admin.Signal.type', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='flyteidl.admin.Signal.value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=659,
  serialized_end=793,
)

_SIGNALGETORCREATEREQUEST.fields_by_name['id'].message_type = flyteidl_dot_core_dot_identifier__pb2._SIGNALIDENTIFIER
_SIGNALGETORCREATEREQUEST.fields_by_name['type'].message_type = flyteidl_dot_core_dot_types__pb2._LITERALTYPE
_SIGNALLISTREQUEST.fields_by_name['workflow_execution_id'].message_type = flyteidl_dot_core_dot_identifier__pb2._WORKFLOWEXECUTIONIDENTIFIER
_SIGNALLISTREQUEST.fields_by_name['sort_by'].message_type = flyteidl_dot_admin_dot_common__pb2._SORT
_SIGNALLIST.fields_by_name['signals'].message_type = _SIGNAL
_SIGNALSETREQUEST.fields_by_name['id'].message_type = flyteidl_dot_core_dot_identifier__pb2._SIGNALIDENTIFIER
_SIGNALSETREQUEST.fields_by_name['value'].message_type = flyteidl_dot_core_dot_literals__pb2._LITERAL
_SIGNAL.fields_by_name['id'].message_type = flyteidl_dot_core_dot_identifier__pb2._SIGNALIDENTIFIER
_SIGNAL.fields_by_name['type'].message_type = flyteidl_dot_core_dot_types__pb2._LITERALTYPE
_SIGNAL.fields_by_name['value'].message_type = flyteidl_dot_core_dot_literals__pb2._LITERAL
DESCRIPTOR.message_types_by_name['SignalGetOrCreateRequest'] = _SIGNALGETORCREATEREQUEST
DESCRIPTOR.message_types_by_name['SignalListRequest'] = _SIGNALLISTREQUEST
DESCRIPTOR.message_types_by_name['SignalList'] = _SIGNALLIST
DESCRIPTOR.message_types_by_name['SignalSetRequest'] = _SIGNALSETREQUEST
DESCRIPTOR.message_types_by_name['SignalSetResponse'] = _SIGNALSETRESPONSE
DESCRIPTOR.message_types_by_name['Signal'] = _SIGNAL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SignalGetOrCreateRequest = _reflection.GeneratedProtocolMessageType('SignalGetOrCreateRequest', (_message.Message,), dict(
  DESCRIPTOR = _SIGNALGETORCREATEREQUEST,
  __module__ = 'flyteidl.admin.signal_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.SignalGetOrCreateRequest)
  ))
_sym_db.RegisterMessage(SignalGetOrCreateRequest)

SignalListRequest = _reflection.GeneratedProtocolMessageType('SignalListRequest', (_message.Message,), dict(
  DESCRIPTOR = _SIGNALLISTREQUEST,
  __module__ = 'flyteidl.admin.signal_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.SignalListRequest)
  ))
_sym_db.RegisterMessage(SignalListRequest)

SignalList = _reflection.GeneratedProtocolMessageType('SignalList', (_message.Message,), dict(
  DESCRIPTOR = _SIGNALLIST,
  __module__ = 'flyteidl.admin.signal_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.SignalList)
  ))
_sym_db.RegisterMessage(SignalList)

SignalSetRequest = _reflection.GeneratedProtocolMessageType('SignalSetRequest', (_message.Message,), dict(
  DESCRIPTOR = _SIGNALSETREQUEST,
  __module__ = 'flyteidl.admin.signal_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.SignalSetRequest)
  ))
_sym_db.RegisterMessage(SignalSetRequest)

SignalSetResponse = _reflection.GeneratedProtocolMessageType('SignalSetResponse', (_message.Message,), dict(
  DESCRIPTOR = _SIGNALSETRESPONSE,
  __module__ = 'flyteidl.admin.signal_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.SignalSetResponse)
  ))
_sym_db.RegisterMessage(SignalSetResponse)

Signal = _reflection.GeneratedProtocolMessageType('Signal', (_message.Message,), dict(
  DESCRIPTOR = _SIGNAL,
  __module__ = 'flyteidl.admin.signal_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.Signal)
  ))
_sym_db.RegisterMessage(Signal)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/admin/description_entity.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.core import identifier_pb2 as flyteidl_dot_core_dot_identifier__pb2
from flyteidl.admin import common_pb2 as flyteidl_dot_admin_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/admin/description_entity.proto',
  package='flyteidl.admin',
  syntax='proto3',
  serialized_options=_b('Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/admin'),
  serialized_pb=_b('\n\'flyteidl/admin/description_entity.proto\x12\x0e\x66lyteidl.admin\x1a\x1e\x66lyteidl/core/identifier.proto\x1a\x1b\x66lyteidl/admin/common.proto\"\xcb\x01\n\x11\x44\x65scriptionEntity\x12%\n\x02id\x18\x01 \x01(\x0b\x32\x19.flyteidl.core.Identifier\x12\x19\n\x11short_description\x18\x02 \x01(\t\x12\x35\n\x10long_description\x18\x03 \x01(\x0b\x32\x1b.flyteidl.admin.Description\x12/\n\x0bsource_code\x18\x04 \x01(\x0b\x32\x1a.flyteidl.admin.SourceCode\x12\x0c\n\x04tags\x18\x05 \x03(\t\"~\n\x0b\x44\x65scription\x12\x0f\n\x05value\x18\x01 \x01(\tH\x00\x12\r\n\x03uri\x18\x02 \x01(\tH\x00\x12\x31\n\x06\x66ormat\x18\x03 \x01(\x0e\x32!.flyteidl.admin.DescriptionFormat\x12\x11\n\ticon_link\x18\x04 \x01(\tB\t\n\x07\x63ontent\"\x1a\n\nSourceCode\x12\x0c\n\x04link\x18\x01 \x01(\t\"f\n\x15\x44\x65scriptionEntityList\x12>\n\x13\x64\x65scriptionEntities\x18\x01 \x03(\x0b\x32!.flyteidl.admin.DescriptionEntity\x12\r\n\x05token\x18\x02 \x01(\t\"\xdb\x01\n\x1c\x44\x65scriptionEntityListRequest\x12\x32\n\rresource_type\x18\x01 \x01(\x0e\x32\x1b.flyteidl.core.ResourceType\x12\x31\n\x02id\x18\x02 \x01(\x0b\x32%.flyteidl.admin.NamedEntityIdentifier\x12\r\n\x05limit\x18\x03 \x01(\r\x12\r\n\x05token\x18\x04 \x01(\t\x12\x0f\n\x07\x66ilters\x18\x05 \x01(\t\x12%\n\x07sort_by\x18\x06 \x01(\x0b\x32\x14.flyteidl.admin.Sort*\x8d\x01\n\x11\x44\x65scriptionFormat\x12\x1e\n\x1a\x44\x45SCRIPTION_FORMAT_UNKNOWN\x10\x00\x12\x1f\n\x1b\x44\x45SCRIPTION_FORMAT_MARKDOWN\x10\x01\x12\x1b\n\x17\x44\x45SCRIPTION_FORMAT_HTML\x10\x02\x12\x1a\n\x16\x44\x45SCRIPTION_FORMAT_RST\x10\x03\x42\x37Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/adminb\x06proto3')
  ,
  dependencies=[flyteidl_dot_core_dot_identifier__pb2.DESCRIPTOR,flyteidl_dot_admin_dot_common__pb2.DESCRIPTOR,])

_DESCRIPTIONFORMAT = _descriptor.EnumDescriptor(
  name='DescriptionFormat',
  full_name='flyteidl.admin.DescriptionFormat',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DESCRIPTION_FORMAT_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DESCRIPTION_FORMAT_MARKDOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DESCRIPTION_FORMAT_HTML', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DESCRIPTION_FORMAT_RST', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=809,
  serialized_end=950,
)
_sym_db.RegisterEnumDescriptor(_DESCRIPTIONFORMAT)

DescriptionFormat = enum_type_wrapper.EnumTypeWrapper(_DESCRIPTIONFORMAT)
DESCRIPTION_FORMAT_UNKNOWN = 0
DESCRIPTION_FORMAT_MARKDOWN = 1
DESCRIPTION_FORMAT_HTML = 2
DESCRIPTION_FORMAT_RST = 3



_DESCRIPTIONENTITY = _descriptor.Descriptor(
  name='DescriptionEntity',
  full_name='flyteidl.admin.DescriptionEntity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.admin.DescriptionEntity.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='short_description', full_name='flyteidl.admin.DescriptionEntity.short_description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='long_description', full_name='flyteidl.admin.DescriptionEntity.long_description', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source_code', full_name='flyteidl.admin.DescriptionEntity.source_code', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='flyteidl.admin.DescriptionEntity.tags', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=324,
)


_DESCRIPTION = _descriptor.Descriptor(
  name='Description',
  full_name='flyteidl.admin.Description',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='flyteidl.admin.Description.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uri', full_name='flyteidl.admin.Description.uri', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format', full_name='flyteidl.admin.Description.format', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='icon_link', full_name='flyteidl.admin.Description.icon_link', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='content', full_name='flyteidl.admin.Description.content',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=326,
  serialized_end=452,
)


_SOURCECODE = _descriptor.Descriptor(
  name='SourceCode',
  full_name='flyteidl.admin.SourceCode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='link', full_name='flyteidl.admin.SourceCode.link', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=454,
  serialized_end=480,
)


_DESCRIPTIONENTITYLIST = _descriptor.Descriptor(
  name='DescriptionEntityList',
  full_name='flyteidl.admin.DescriptionEntityList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='descriptionEntities', full_name='flyteidl.admin.DescriptionEntityList.descriptionEntities', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token', full_name='flyteidl.admin.DescriptionEntityList.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=482,
  serialized_end=584,
)


_DESCRIPTIONENTITYLISTREQUEST = _descriptor.Descriptor(
  name='DescriptionEntityListRequest',
  full_name='flyteidl.admin.DescriptionEntityListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_type', full_name='flyteidl.admin.DescriptionEntityListRequest.resource_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.admin.DescriptionEntityListRequest.id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='flyteidl.admin.DescriptionEntityListRequest.limit', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token', full_name='flyteidl.admin.DescriptionEntityListRequest.token', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filters', full_name='flyteidl.admin.DescriptionEntityListRequest.filters', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sort_by', full_name='flyteidl.admin.DescriptionEntityListRequest.sort_by', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=587,
  serialized_end=806,
)

_DESCRIPTIONENTITY.fields_by_name['id'].message_type = flyteidl_dot_core_dot_identifier__pb2._IDENTIFIER
_DESCRIPTIONENTITY.fields_by_name['long_description'].message_type = _DESCRIPTION
_DESCRIPTIONENTITY.fields_by_name['source_code'].message_type = _SOURCECODE
_DESCRIPTION.fields_by_name['format'].enum_type = _DESCRIPTIONFORMAT
_DESCRIPTION.oneofs_by_name['content'].fields.append(
  _DESCRIPTION.fields_by_name['value'])
_DESCRIPTION.fields_by_name['value'].containing_oneof = _DESCRIPTION.oneofs_by_name['content']
_DESCRIPTION.oneofs_by_name['content'].fields.append(
  _DESCRIPTION.fields_by_name['uri'])
_DESCRIPTION.fields_by_name['uri'].containing_oneof = _DESCRIPTION.oneofs_by_name['content']
_DESCRIPTIONENTITYLIST.fields_by_name['descriptionEntities'].message_type = _DESCRIPTIONENTITY
_DESCRIPTIONENTITYLISTREQUEST.fields_by_name['resource_type'].enum_type = flyteidl_dot_core_dot_identifier__pb2._RESOURCETYPE
_DESCRIPTIONENTITYLISTREQUEST.fields_by_name['id'].message_type = flyteidl_dot_admin_dot_common__pb2._NAMEDENTITYIDENTIFIER
_DESCRIPTIONENTITYLISTREQUEST.fields_by_name['sort_by'].message_type = flyteidl_dot_admin_dot_common__pb2._SORT
DESCRIPTOR.message_types_by_name['DescriptionEntity'] = _DESCRIPTIONENTITY
DESCRIPTOR.message_types_by_name['Description'] = _DESCRIPTION
DESCRIPTOR.message_types_by_name['SourceCode'] = _SOURCECODE
DESCRIPTOR.message_types_by_name['DescriptionEntityList'] = _DESCRIPTIONENTITYLIST
DESCRIPTOR.message_types_by_name['DescriptionEntityListRequest'] = _DESCRIPTIONENTITYLISTREQUEST
DESCRIPTOR.enum_types_by_name['DescriptionFormat'] = _DESCRIPTIONFORMAT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DescriptionEntity = _reflection.GeneratedProtocolMessageType('DescriptionEntity', (_message.Message,), dict(
  DESCRIPTOR = _DESCRIPTIONENTITY,
  __module__ = 'flyteidl.admin.description_entity_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.DescriptionEntity)
  ))
_sym_db.RegisterMessage(DescriptionEntity)

Description = _reflection.GeneratedProtocolMessageType('Description', (_message.Message,), dict(
  DESCRIPTOR = _DESCRIPTION,
  __module__ = 'flyteidl.admin.description_entity_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.Description)
  ))
_sym_db.RegisterMessage(Description)

SourceCode = _reflection.GeneratedProtocolMessageType('SourceCode', (_message.Message,), dict(
  DESCRIPTOR = _SOURCECODE,
  __module__ = 'flyteidl.admin.description_entity_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.SourceCode)
  ))
_sym_db.RegisterMessage(SourceCode)

DescriptionEntityList = _reflection.GeneratedProtocolMessageType('DescriptionEntityList', (_message.Message,), dict(
  DESCRIPTOR = _DESCRIPTIONENTITYLIST,
  __module__ = 'flyteidl.admin.description_entity_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.DescriptionEntityList)
  ))
_sym_db.RegisterMessage(DescriptionEntityList)

DescriptionEntityListRequest = _reflection.GeneratedProtocolMessageType('DescriptionEntityListRequest', (_message.Message,), dict(
  DESCRIPTOR = _DESCRIPTIONENTITYLISTREQUEST,
  __module__ = 'flyteidl.admin.description_entity_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.DescriptionEntityListRequest)
  ))
_sym_db.RegisterMessage(DescriptionEntityListRequest)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from flyteidl.service import external_plugin_service_pb2 as flyteidl_dot_service_dot_external__plugin__service__pb2


class ExternalPluginServiceStub(object):
  """ExternalPluginService defines an RPC Service that allows propeller to send the request to the backend plugin server.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.CreateTask = channel.unary_unary(
        '/flyteidl.service.ExternalPluginService/CreateTask',
        request_serializer=flyteidl_dot_service_dot_external__plugin__service__pb2.TaskCreateRequest.SerializeToString,
        response_deserializer=flyteidl_dot_service_dot_external__plugin__service__pb2.TaskCreateResponse.FromString,
        )
    self.GetTask = channel.unary_unary(
        '/flyteidl.service.ExternalPluginService/GetTask',
        request_serializer=flyteidl_dot_service_dot_external__plugin__service__pb2.TaskGetRequest.SerializeToString,
        response_deserializer=flyteidl_dot_service_dot_external__plugin__service__pb2.TaskGetResponse.FromString,
        )
    self.DeleteTask = channel.unary_unary(
        '/flyteidl.service.ExternalPluginService/DeleteTask',
        request_serializer=flyteidl_dot_service_dot_external__plugin__service__pb2.TaskDeleteRequest.SerializeToString,
        response_deserializer=flyteidl_dot_service_dot_external__plugin__service__pb2.TaskDeleteResponse.FromString,
        )


class ExternalPluginServiceServicer(object):
  """ExternalPluginService defines an RPC Service that allows propeller to send the request to the backend plugin server.
  """

  def CreateTask(self, request, context):
    """Send a task create request to the backend plugin server.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetTask(self, request, context):
    """Get job status.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteTask(self, request, context):
    """Delete the task resource.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ExternalPluginServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'CreateTask': grpc.unary_unary_rpc_method_handler(
          servicer.CreateTask,
          request_deserializer=flyteidl_dot_service_dot_external__plugin__service__pb2.TaskCreateRequest.FromString,
          response_serializer=flyteidl_dot_service_dot_external__plugin__service__pb2.TaskCreateResponse.SerializeToString,
      ),
      'GetTask': grpc.unary_unary_rpc_method_handler(
          servicer.GetTask,
          request_deserializer=flyteidl_dot_service_dot_external__plugin__service__pb2.TaskGetRequest.FromString,
          response_serializer=flyteidl_dot_service_dot_external__plugin__service__pb2.TaskGetResponse.SerializeToString,
      ),
      'DeleteTask': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteTask,
          request_deserializer=flyteidl_dot_service_dot_external__plugin__service__pb2.TaskDeleteRequest.FromString,
          response_serializer=flyteidl_dot_service_dot_external__plugin__service__pb2.TaskDeleteResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'flyteidl.service.ExternalPluginService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/service/signal.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from flyteidl.admin import signal_pb2 as flyteidl_dot_admin_dot_signal__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/service/signal.proto',
  package='flyteidl.service',
  syntax='proto3',
  serialized_options=_b('Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/service'),
  serialized_pb=_b('\n\x1d\x66lyteidl/service/signal.proto\x12\x10\x66lyteidl.service\x1a\x1cgoogle/api/annotations.proto\x1a\x1b\x66lyteidl/admin/signal.proto2\x9a\x03\n\rSignalService\x12W\n\x11GetOrCreateSignal\x12(.flyteidl.admin.SignalGetOrCreateRequest\x1a\x16.flyteidl.admin.Signal\"\x00\x12\xc1\x01\n\x0bListSignals\x12!.flyteidl.admin.SignalListRequest\x1a\x1a.flyteidl.admin.SignalList\"s\x82\xd3\xe4\x93\x02m\x12k/api/v1/signals/{workflow_execution_id.project}/{workflow_execution_id.domain}/{workflow_execution_id.name}\x12l\n\tSetSignal\x12 .flyteidl.admin.SignalSetRequest\x1a!.flyteidl.admin.SignalSetResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/api/v1/signals:\x01*B9Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/serviceb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,flyteidl_dot_admin_dot_signal__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_SIGNALSERVICE = _descriptor.ServiceDescriptor(
  name='SignalService',
  full_name='flyteidl.service.SignalService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=111,
  serialized_end=521,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetOrCreateSignal',
    full_name='flyteidl.service.SignalService.GetOrCreateSignal',
    index=0,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_signal__pb2._SIGNALGETORCREATEREQUEST,
    output_type=flyteidl_dot_admin_dot_signal__pb2._SIGNAL,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListSignals',
    full_name='flyteidl.service.SignalService.ListSignals',
    index=1,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_signal__pb2._SIGNALLISTREQUEST,
    output_type=flyteidl_dot_admin_dot_signal__pb2._SIGNALLIST,
    serialized_options=_b('\202\323\344\223\002m\022k/api/v1/signals/{workflow_execution_id.project}/{workflow_execution_id.domain}/{workflow_execution_id.name}'),
  ),
  _descriptor.MethodDescriptor(
    name='SetSignal',
    full_name='flyteidl.service.SignalService.SetSignal',
    index=2,
    containing_service=None,
    input_type=flyteidl_dot_admin_dot_signal__pb2._SIGNALSETREQUEST,
    output_type=flyteidl_dot_admin_dot_signal__pb2._SIGNALSETRESPONSE,
    serialized_options=_b('\202\323\344\223\002\024\"\017/api/v1/signals:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_SIGNALSERVICE)

DESCRIPTOR.services_by_name['SignalService'] = _SIGNALSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/service/dataproxy.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from flyteidl.core import identifier_pb2 as flyteidl_dot_core_dot_identifier__pb2
from flyteidl.core import literals_pb2 as flyteidl_dot_core_dot_literals__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/service/dataproxy.proto',
  package='flyteidl.service',
  syntax='proto3',
  serialized_options=_b('Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/service'),
  serialized_pb=_b('\n flyteidl/service/dataproxy.proto\x12\x10\x66lyteidl.service\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1e\x66lyteidl/core/identifier.proto\x1a\x1c\x66lyteidl/core/literals.proto\"v\n\x1c\x43reateUploadLocationResponse\x12\x12\n\nsigned_url\x18\x01 \x01(\t\x12\x12\n\nnative_url\x18\x02 \x01(\t\x12.\n\nexpires_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x94\x01\n\x1b\x43reateUploadLocationRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\x12\x10\n\x08\x66ilename\x18\x03 \x01(\t\x12-\n\nexpires_in\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x13\n\x0b\x63ontent_md5\x18\x05 \x01(\x0c\"f\n\x1d\x43reateDownloadLocationRequest\x12\x12\n\nnative_url\x18\x01 \x01(\t\x12-\n\nexpires_in\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration:\x02\x18\x01\"h\n\x1e\x43reateDownloadLocationResponse\x12\x12\n\nsigned_url\x18\x01 \x01(\t\x12.\n\nexpires_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp:\x02\x18\x01\"\xd0\x01\n\x19\x43reateDownloadLinkRequest\x12\x35\n\rartifact_type\x18\x01 \x01(\x0e\x32\x1e.flyteidl.service.ArtifactType\x12-\n\nexpires_in\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x43\n\x11node_execution_id\x18\x03 \x01(\x0b\x32&.flyteidl.core.NodeExecutionIdentifierH\x00\x42\x08\n\x06source\"\xa2\x01\n\x1a\x43reateDownloadLinkResponse\x12\x16\n\nsigned_url\x18\x01 \x03(\tB\x02\x18\x01\x12\x32\n\nexpires_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x02\x18\x01\x12\x38\n\x0fpre_signed_urls\x18\x03 \x01(\x0b\x32\x1f.flyteidl.service.PreSignedURLs\"S\n\rPreSignedURLs\x12\x12\n\nsigned_url\x18\x01 \x03(\t\x12.\n\nexpires_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"#\n\x0eGetDataRequest\x12\x11\n\tflyte_url\x18\x01 \x01(\t\"\x87\x01\n\x0fGetDataResponse\x12\x30\n\x0bliteral_map\x18\x01 \x01(\x0b\x32\x19.flyteidl.core.LiteralMapH\x00\x12:\n\x0fpre_signed_urls\x18\x02 \x01(\x0b\x32\x1f.flyteidl.service.PreSignedURLsH\x00\x42\x06\n\x04\x64\x61ta*C\n\x0c\x41rtifactType\x12\x1b\n\x17\x41RTIFACT_TYPE_UNDEFINED\x10\x00\x12\x16\n\x12\x41RTIFACT_TYPE_DECK\x10\x01\x32\xe2\x04\n\x10\x44\x61taProxyService\x12\xa0\x01\n\x14\x43reateUploadLocation\x12-.flyteidl.service.CreateUploadLocationRequest\x1a..flyteidl.service.CreateUploadLocationResponse\")\x82\xd3\xe4\x93\x02#\"\x1e/api/v1/dataproxy/artifact_urn:\x01*\x12\xa6\x01\n\x16\x43reateDownloadLocation\x12/.flyteidl.service.CreateDownloadLocationRequest\x1a\x30.flyteidl.service.CreateDownloadLocationResponse\")\x88\x02\x01\x82\xd3\xe4\x93\x02 \x12\x1e/api/v1/dataproxy/artifact_urn\x12\x9b\x01\n\x12\x43reateDownloadLink\x12+.flyteidl.service.CreateDownloadLinkRequest\x1a,.flyteidl.service.CreateDownloadLinkResponse\"*\x82\xd3\xe4\x93\x02$\"\x1f/api/v1/dataproxy/artifact_link:\x01*\x12\x64\n\x07GetData\x12 .flyteidl.service.GetDataRequest\x1a!.flyteidl.service.GetDataResponse\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/api/v1/dataB9Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/serviceb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,flyteidl_dot_core_dot_identifier__pb2.DESCRIPTOR,flyteidl_dot_core_dot_literals__pb2.DESCRIPTOR,])

_ARTIFACTTYPE = _descriptor.EnumDescriptor(
  name='ArtifactType',
  full_name='flyteidl.service.ArtifactType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ARTIFACT_TYPE_UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ARTIFACT_TYPE_DECK', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1328,
  serialized_end=1395,
)
_sym_db.RegisterEnumDescriptor(_ARTIFACTTYPE)

ArtifactType = enum_type_wrapper.EnumTypeWrapper(_ARTIFACTTYPE)
ARTIFACT_TYPE_UNDEFINED = 0
ARTIFACT_TYPE_DECK = 1



_CREATEUPLOADLOCATIONRESPONSE = _descriptor.Descriptor(
  name='CreateUploadLocationResponse',
  full_name='flyteidl.service.CreateUploadLocationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signed_url', full_name='flyteidl.service.CreateUploadLocationResponse.signed_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='native_url', full_name='flyteidl.service.CreateUploadLocationResponse.native_url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expires_at', full_name='flyteidl.service.CreateUploadLocationResponse.expires_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=211,
  serialized_end=329,
)


_CREATEUPLOADLOCATIONREQUEST = _descriptor.Descriptor(
  name='CreateUploadLocationRequest',
  full_name='flyteidl.service.CreateUploadLocationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='flyteidl.service.CreateUploadLocationRequest.project', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='domain', full_name='flyteidl.service.CreateUploadLocationRequest.domain', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filename', full_name='flyteidl.service.CreateUploadLocationRequest.filename', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expires_in', full_name='flyteidl.service.CreateUploadLocationRequest.expires_in', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content_md5', full_name='flyteidl.service.CreateUploadLocationRequest.content_md5', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=332,
  serialized_end=480,
)


_CREATEDOWNLOADLOCATIONREQUEST = _descriptor.Descriptor(
  name='CreateDownloadLocationRequest',
  full_name='flyteidl.service.CreateDownloadLocationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='native_url', full_name='flyteidl.service.CreateDownloadLocationRequest.native_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expires_in', full_name='flyteidl.service.CreateDownloadLocationRequest.expires_in', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\030\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=482,
  serialized_end=584,
)


_CREATEDOWNLOADLOCATIONRESPONSE = _descriptor.Descriptor(
  name='CreateDownloadLocationResponse',
  full_name='flyteidl.service.CreateDownloadLocationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signed_url', full_name='flyteidl.service.CreateDownloadLocationResponse.signed_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expires_at', full_name='flyteidl.service.CreateDownloadLocationResponse.expires_at', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\030\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=586,
  serialized_end=690,
)


_CREATEDOWNLOADLINKREQUEST = _descriptor.Descriptor(
  name='CreateDownloadLinkRequest',
  full_name='flyteidl.service.CreateDownloadLinkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='artifact_type', full_name='flyteidl.service.CreateDownloadLinkRequest.artifact_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expires_in', full_name='flyteidl.service.CreateDownloadLinkRequest.expires_in', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node_execution_id', full_name='flyteidl.service.CreateDownloadLinkRequest.node_execution_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='source', full_name='flyteidl.service.CreateDownloadLinkRequest.source',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=693,
  serialized_end=901,
)


_CREATEDOWNLOADLINKRESPONSE = _descriptor.Descriptor(
  name='CreateDownloadLinkResponse',
  full_name='flyteidl.service.CreateDownloadLinkResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signed_url', full_name='flyteidl.service.CreateDownloadLinkResponse.signed_url', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expires_at', full_name='flyteidl.service.CreateDownloadLinkResponse.expires_at', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pre_signed_urls', full_name='flyteidl.service.CreateDownloadLinkResponse.pre_signed_urls', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=904,
  serialized_end=1066,
)


_PRESIGNEDURLS = _descriptor.Descriptor(
  name='PreSignedURLs',
  full_name='flyteidl.service.PreSignedURLs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signed_url', full_name='flyteidl.service.PreSignedURLs.signed_url', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expires_at', full_name='flyteidl.service.PreSignedURLs.expires_at', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1068,
  serialized_end=1151,
)


_GETDATAREQUEST = _descriptor.Descriptor(
  name='GetDataRequest',
  full_name='flyteidl.service.GetDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='flyte_url', full_name='flyteidl.service.GetDataRequest.flyte_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1153,
  serialized_end=1188,
)


_GETDATARESPONSE = _descriptor.Descriptor(
  name='GetDataResponse',
  full_name='flyteidl.service.GetDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='literal_map', full_name='flyteidl.service.GetDataResponse.literal_map', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pre_signed_urls', full_name='flyteidl.service.GetDataResponse.pre_signed_urls', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='flyteidl.service.GetDataResponse.data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1191,
  serialized_end=1326,
)

_CREATEUPLOADLOCATIONRESPONSE.fields_by_name['expires_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CREATEUPLOADLOCATIONREQUEST.fields_by_name['expires_in'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_CREATEDOWNLOADLOCATIONREQUEST.fields_by_name['expires_in'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_CREATEDOWNLOADLOCATIONRESPONSE.fields_by_name['expires_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CREATEDOWNLOADLINKREQUEST.fields_by_name['artifact_type'].enum_type = _ARTIFACTTYPE
_CREATEDOWNLOADLINKREQUEST.fields_by_name['expires_in'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_CREATEDOWNLOADLINKREQUEST.fields_by_name['node_execution_id'].message_type = flyteidl_dot_core_dot_identifier__pb2._NODEEXECUTIONIDENTIFIER
_CREATEDOWNLOADLINKREQUEST.oneofs_by_name['source'].fields.append(
  _CREATEDOWNLOADLINKREQUEST.fields_by_name['node_execution_id'])
_CREATEDOWNLOADLINKREQUEST.fields_by_name['node_execution_id'].containing_oneof = _CREATEDOWNLOADLINKREQUEST.oneofs_by_name['source']
_CREATEDOWNLOADLINKRESPONSE.fields_by_name['expires_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CREATEDOWNLOADLINKRESPONSE.fields_by_name['pre_signed_urls'].message_type = _PRESIGNEDURLS
_PRESIGNEDURLS.fields_by_name['expires_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETDATARESPONSE.fields_by_name['literal_map'].message_type = flyteidl_dot_core_dot_literals__pb2._LITERALMAP
_GETDATARESPONSE.fields_by_name['pre_signed_urls'].message_type = _PRESIGNEDURLS
_GETDATARESPONSE.oneofs_by_name['data'].fields.append(
  _GETDATARESPONSE.fields_by_name['literal_map'])
_GETDATARESPONSE.fields_by_name['literal_map'].containing_oneof = _GETDATARESPONSE.oneofs_by_name['data']
_GETDATARESPONSE.oneofs_by_name['data'].fields.append(
  _GETDATARESPONSE.fields_by_name['pre_signed_urls'])
_GETDATARESPONSE.fields_by_name['pre_signed_urls'].containing_oneof = _GETDATARESPONSE.oneofs_by_name['data']
DESCRIPTOR.message_types_by_name['CreateUploadLocationResponse'] = _CREATEUPLOADLOCATIONRESPONSE
DESCRIPTOR.message_types_by_name['CreateUploadLocationRequest'] = _CREATEUPLOADLOCATIONREQUEST
DESCRIPTOR.message_types_by_name['CreateDownloadLocationRequest'] = _CREATEDOWNLOADLOCATIONREQUEST
DESCRIPTOR.message_types_by_name['CreateDownloadLocationResponse'] = _CREATEDOWNLOADLOCATIONRESPONSE
DESCRIPTOR.message_types_by_name['CreateDownloadLinkRequest'] = _CREATEDOWNLOADLINKREQUEST
DESCRIPTOR.message_types_by_name['CreateDownloadLinkResponse'] = _CREATEDOWNLOADLINKRESPONSE
DESCRIPTOR.message_types_by_name['PreSignedURLs'] = _PRESIGNEDURLS
DESCRIPTOR.message_types_by_name['GetDataRequest'] = _GETDATAREQUEST
DESCRIPTOR.message_types_by_name['GetDataResponse'] = _GETDATARESPONSE
DESCRIPTOR.enum_types_by_name['ArtifactType'] = _ARTIFACTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateUploadLocationResponse = _reflection.GeneratedProtocolMessageType('CreateUploadLocationResponse', (_message.Message,), dict(
  DESCRIPTOR = _CREATEUPLOADLOCATIONRESPONSE,
  __module__ = 'flyteidl.service.dataproxy_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.service.CreateUploadLocationResponse)
  ))
_sym_db.RegisterMessage(CreateUploadLocationResponse)

CreateUploadLocationRequest = _reflection.GeneratedProtocolMessageType('CreateUploadLocationRequest', (_message.Message,), dict(
  DESCRIPTOR = _CREATEUPLOADLOCATIONREQUEST,
  __module__ = 'flyteidl.service.dataproxy_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.service.CreateUploadLocationRequest)
  ))
_sym_db.RegisterMessage(CreateUploadLocationRequest)

CreateDownloadLocationRequest = _reflection.GeneratedProtocolMessageType('CreateDownloadLocationRequest', (_message.Message,), dict(
  DESCRIPTOR = _CREATEDOWNLOADLOCATIONREQUEST,
  __module__ = 'flyteidl.service.dataproxy_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.service.CreateDownloadLocationRequest)
  ))
_sym_db.RegisterMessage(CreateDownloadLocationRequest)

CreateDownloadLocationResponse = _reflection.GeneratedProtocolMessageType('CreateDownloadLocationResponse', (_message.Message,), dict(
  DESCRIPTOR = _CREATEDOWNLOADLOCATIONRESPONSE,
  __module__ = 'flyteidl.service.dataproxy_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.service.CreateDownloadLocationResponse)
  ))
_sym_db.RegisterMessage(CreateDownloadLocationResponse)

CreateDownloadLinkRequest = _reflection.GeneratedProtocolMessageType('CreateDownloadLinkRequest', (_message.Message,), dict(
  DESCRIPTOR = _CREATEDOWNLOADLINKREQUEST,
  __module__ = 'flyteidl.service.dataproxy_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.service.CreateDownloadLinkRequest)
  ))
_sym_db.RegisterMessage(CreateDownloadLinkRequest)

CreateDownloadLinkResponse = _reflection.GeneratedProtocolMessageType('CreateDownloadLinkResponse', (_message.Message,), dict(
  DESCRIPTOR = _CREATEDOWNLOADLINKRESPONSE,
  __module__ = 'flyteidl.service.dataproxy_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.service.CreateDownloadLinkResponse)
  ))
_sym_db.RegisterMessage(CreateDownloadLinkResponse)

PreSignedURLs = _reflection.GeneratedProtocolMessageType('PreSignedURLs', (_message.Message,), dict(
  DESCRIPTOR = _PRESIGNEDURLS,
  __module__ = 'flyteidl.service.dataproxy_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.service.PreSignedURLs)
  ))
_sym_db.RegisterMessage(PreSignedURLs)

GetDataRequest = _reflection.GeneratedProtocolMessageType('GetDataRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETDATAREQUEST,
  __module__ = 'flyteidl.service.dataproxy_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.service.GetDataRequest)
  ))
_sym_db.RegisterMessage(GetDataRequest)

GetDataResponse = _reflection.GeneratedProtocolMessageType('GetDataResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETDATARESPONSE,
  __module__ = 'flyteidl.service.dataproxy_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.service.GetDataResponse)
  ))
_sym_db.RegisterMessage(GetDataResponse)


DESCRIPTOR._options = None
_CREATEDOWNLOADLOCATIONREQUEST._options = None
_CREATEDOWNLOADLOCATIONRESPONSE._options = None
_CREATEDOWNLOADLINKRESPONSE.fields_by_name['signed_url']._options = None
_CREATEDOWNLOADLINKRESPONSE.fields_by_name['expires_at']._options = None

_DATAPROXYSERVICE = _descriptor.ServiceDescriptor(
  name='DataProxyService',
  full_name='flyteidl.service.DataProxyService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1398,
  serialized_end=2008,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateUploadLocation',
    full_name='flyteidl.service.DataProxyService.CreateUploadLocation',
    index=0,
    containing_service=None,
    input_type=_CREATEUPLOADLOCATIONREQUEST,
    output_type=_CREATEUPLOADLOCATIONRESPONSE,
    serialized_options=_b('\202\323\344\223\002#\"\036/api/v1/dataproxy/artifact_urn:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='CreateDownloadLocation',
    full_name='flyteidl.service.DataProxyService.CreateDownloadLocation',
    index=1,
    containing_service=None,
    input_type=_CREATEDOWNLOADLOCATIONREQUEST,
    output_type=_CREATEDOWNLOADLOCATIONRESPONSE,
    serialized_options=_b('\210\002\001\202\323\344\223\002 \022\036/api/v1/dataproxy/artifact_urn'),
  ),
  _descriptor.MethodDescriptor(
    name='CreateDownloadLink',
    full_name='flyteidl.service.DataProxyService.CreateDownloadLink',
    index=2,
    containing_service=None,
    input_type=_CREATEDOWNLOADLINKREQUEST,
    output_type=_CREATEDOWNLOADLINKRESPONSE,
    serialized_options=_b('\202\323\344\223\002$\"\037/api/v1/dataproxy/artifact_link:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='GetData',
    full_name='flyteidl.service.DataProxyService.GetData',
    index=3,
    containing_service=None,
    input_type=_GETDATAREQUEST,
    output_type=_GETDATARESPONSE,
    serialized_options=_b('\202\323\344\223\002\016\022\014/api/v1/data'),
  ),
])
_sym_db.RegisterServiceDescriptor(_DATAPROXYSERVICE)

DESCRIPTOR.services_by_name['DataProxyService'] = _DATAPROXYSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/plugins/kubeflow/tensorflow.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.core import tasks_pb2 as flyteidl_dot_core_dot_tasks__pb2
from flyteidl.plugins.kubeflow import common_pb2 as flyteidl_dot_plugins_dot_kubeflow_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/plugins/kubeflow/tensorflow.proto',
  package='flyteidl.plugins.kubeflow',
  syntax='proto3',
  serialized_options=_b('Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/plugins'),
  serialized_pb=_b('\n*flyteidl/plugins/kubeflow/tensorflow.proto\x12\x19\x66lyteidl.plugins.kubeflow\x1a\x19\x66lyteidl/core/tasks.proto\x1a&flyteidl/plugins/kubeflow/common.proto\"\xf2\x02\n!DistributedTensorflowTrainingTask\x12\\\n\x0fworker_replicas\x18\x01 \x01(\x0b\x32\x43.flyteidl.plugins.kubeflow.DistributedTensorflowTrainingReplicaSpec\x12X\n\x0bps_replicas\x18\x02 \x01(\x0b\x32\x43.flyteidl.plugins.kubeflow.DistributedTensorflowTrainingReplicaSpec\x12[\n\x0e\x63hief_replicas\x18\x03 \x01(\x0b\x32\x43.flyteidl.plugins.kubeflow.DistributedTensorflowTrainingReplicaSpec\x12\x38\n\nrun_policy\x18\x04 \x01(\x0b\x32$.flyteidl.plugins.kubeflow.RunPolicy\"\xba\x01\n(DistributedTensorflowTrainingReplicaSpec\x12\x10\n\x08replicas\x18\x01 \x01(\x05\x12\r\n\x05image\x18\x02 \x01(\t\x12+\n\tresources\x18\x03 \x01(\x0b\x32\x18.flyteidl.core.Resources\x12@\n\x0erestart_policy\x18\x04 \x01(\x0e\x32(.flyteidl.plugins.kubeflow.RestartPolicyB9Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/pluginsb\x06proto3')
  ,
  dependencies=[flyteidl_dot_core_dot_tasks__pb2.DESCRIPTOR,flyteidl_dot_plugins_dot_kubeflow_dot_common__pb2.DESCRIPTOR,])




_DISTRIBUTEDTENSORFLOWTRAININGTASK = _descriptor.Descriptor(
  name='DistributedTensorflowTrainingTask',
  full_name='flyteidl.plugins.kubeflow.DistributedTensorflowTrainingTask',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='worker_replicas', full_name='flyteidl.plugins.kubeflow.DistributedTensorflowTrainingTask.worker_replicas', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ps_replicas', full_name='flyteidl.plugins.kubeflow.DistributedTensorflowTrainingTask.ps_replicas', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chief_replicas', full_name='flyteidl.plugins.kubeflow.DistributedTensorflowTrainingTask.chief_replicas', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='run_policy', full_name='flyteidl.plugins.kubeflow.DistributedTensorflowTrainingTask.run_policy', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=141,
  serialized_end=511,
)


_DISTRIBUTEDTENSORFLOWTRAININGREPLICASPEC = _descriptor.Descriptor(
  name='DistributedTensorflowTrainingReplicaSpec',
  full_name='flyteidl.plugins.kubeflow.DistributedTensorflowTrainingReplicaSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='replicas', full_name='flyteidl.plugins.kubeflow.DistributedTensorflowTrainingReplicaSpec.replicas', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image', full_name='flyteidl.plugins.kubeflow.DistributedTensorflowTrainingReplicaSpec.image', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resources', full_name='flyteidl.plugins.kubeflow.DistributedTensorflowTrainingReplicaSpec.resources', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='restart_policy', full_name='flyteidl.plugins.kubeflow.DistributedTensorflowTrainingReplicaSpec.restart_policy', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=514,
  serialized_end=700,
)

_DISTRIBUTEDTENSORFLOWTRAININGTASK.fields_by_name['worker_replicas'].message_type = _DISTRIBUTEDTENSORFLOWTRAININGREPLICASPEC
_DISTRIBUTEDTENSORFLOWTRAININGTASK.fields_by_name['ps_replicas'].message_type = _DISTRIBUTEDTENSORFLOWTRAININGREPLICASPEC
_DISTRIBUTEDTENSORFLOWTRAININGTASK.fields_by_name['chief_replicas'].message_type = _DISTRIBUTEDTENSORFLOWTRAININGREPLICASPEC
_DISTRIBUTEDTENSORFLOWTRAININGTASK.fields_by_name['run_policy'].message_type = flyteidl_dot_plugins_dot_kubeflow_dot_common__pb2._RUNPOLICY
_DISTRIBUTEDTENSORFLOWTRAININGREPLICASPEC.fields_by_name['resources'].message_type = flyteidl_dot_core_dot_tasks__pb2._RESOURCES
_DISTRIBUTEDTENSORFLOWTRAININGREPLICASPEC.fields_by_name['restart_policy'].enum_type = flyteidl_dot_plugins_dot_kubeflow_dot_common__pb2._RESTARTPOLICY
DESCRIPTOR.message_types_by_name['DistributedTensorflowTrainingTask'] = _DISTRIBUTEDTENSORFLOWTRAININGTASK
DESCRIPTOR.message_types_by_name['DistributedTensorflowTrainingReplicaSpec'] = _DISTRIBUTEDTENSORFLOWTRAININGREPLICASPEC
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DistributedTensorflowTrainingTask = _reflection.GeneratedProtocolMessageType('DistributedTensorflowTrainingTask', (_message.Message,), dict(
  DESCRIPTOR = _DISTRIBUTEDTENSORFLOWTRAININGTASK,
  __module__ = 'flyteidl.plugins.kubeflow.tensorflow_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.kubeflow.DistributedTensorflowTrainingTask)
  ))
_sym_db.RegisterMessage(DistributedTensorflowTrainingTask)

DistributedTensorflowTrainingReplicaSpec = _reflection.GeneratedProtocolMessageType('DistributedTensorflowTrainingReplicaSpec', (_message.Message,), dict(
  DESCRIPTOR = _DISTRIBUTEDTENSORFLOWTRAININGREPLICASPEC,
  __module__ = 'flyteidl.plugins.kubeflow.tensorflow_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.kubeflow.DistributedTensorflowTrainingReplicaSpec)
  ))
_sym_db.RegisterMessage(DistributedTensorflowTrainingReplicaSpec)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/plugins/dask.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.core import tasks_pb2 as flyteidl_dot_core_dot_tasks__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/plugins/dask.proto',
  package='flyteidl.plugins',
  syntax='proto3',
  serialized_options=_b('Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/plugins'),
  serialized_pb=_b('\n\x1b\x66lyteidl/plugins/dask.proto\x12\x10\x66lyteidl.plugins\x1a\x19\x66lyteidl/core/tasks.proto\"q\n\x07\x44\x61skJob\x12\x32\n\tscheduler\x18\x01 \x01(\x0b\x32\x1f.flyteidl.plugins.DaskScheduler\x12\x32\n\x07workers\x18\x02 \x01(\x0b\x32!.flyteidl.plugins.DaskWorkerGroup\"K\n\rDaskScheduler\x12\r\n\x05image\x18\x01 \x01(\t\x12+\n\tresources\x18\x02 \x01(\x0b\x32\x18.flyteidl.core.Resources\"h\n\x0f\x44\x61skWorkerGroup\x12\x19\n\x11number_of_workers\x18\x01 \x01(\r\x12\r\n\x05image\x18\x02 \x01(\t\x12+\n\tresources\x18\x03 \x01(\x0b\x32\x18.flyteidl.core.ResourcesB9Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/pluginsb\x06proto3')
  ,
  dependencies=[flyteidl_dot_core_dot_tasks__pb2.DESCRIPTOR,])




_DASKJOB = _descriptor.Descriptor(
  name='DaskJob',
  full_name='flyteidl.plugins.DaskJob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='scheduler', full_name='flyteidl.plugins.DaskJob.scheduler', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='workers', full_name='flyteidl.plugins.DaskJob.workers', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=76,
  serialized_end=189,
)


_DASKSCHEDULER = _descriptor.Descriptor(
  name='DaskScheduler',
  full_name='flyteidl.plugins.DaskScheduler',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='image', full_name='flyteidl.plugins.DaskScheduler.image', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resources', full_name='flyteidl.plugins.DaskScheduler.resources', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=191,
  serialized_end=266,
)


_DASKWORKERGROUP = _descriptor.Descriptor(
  name='DaskWorkerGroup',
  full_name='flyteidl.plugins.DaskWorkerGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='number_of_workers', full_name='flyteidl.plugins.DaskWorkerGroup.number_of_workers', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image', full_name='flyteidl.plugins.DaskWorkerGroup.image', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resources', full_name='flyteidl.plugins.DaskWorkerGroup.resources', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=268,
  serialized_end=372,
)

_DASKJOB.fields_by_name['scheduler'].message_type = _DASKSCHEDULER
_DASKJOB.fields_by_name['workers'].message_type = _DASKWORKERGROUP
_DASKSCHEDULER.fields_by_name['resources'].message_type = flyteidl_dot_core_dot_tasks__pb2._RESOURCES
_DASKWORKERGROUP.fields_by_name['resources'].message_type = flyteidl_dot_core_dot_tasks__pb2._RESOURCES
DESCRIPTOR.message_types_by_name['DaskJob'] = _DASKJOB
DESCRIPTOR.message_types_by_name['DaskScheduler'] = _DASKSCHEDULER
DESCRIPTOR.message_types_by_name['DaskWorkerGroup'] = _DASKWORKERGROUP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DaskJob = _reflection.GeneratedProtocolMessageType('DaskJob', (_message.Message,), dict(
  DESCRIPTOR = _DASKJOB,
  __module__ = 'flyteidl.plugins.dask_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.DaskJob)
  ))
_sym_db.RegisterMessage(DaskJob)

DaskScheduler = _reflection.GeneratedProtocolMessageType('DaskScheduler', (_message.Message,), dict(
  DESCRIPTOR = _DASKSCHEDULER,
  __module__ = 'flyteidl.plugins.dask_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.DaskScheduler)
  ))
_sym_db.RegisterMessage(DaskScheduler)

DaskWorkerGroup = _reflection.GeneratedProtocolMessageType('DaskWorkerGroup', (_message.Message,), dict(
  DESCRIPTOR = _DASKWORKERGROUP,
  __module__ = 'flyteidl.plugins.dask_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.DaskWorkerGroup)
  ))
_sym_db.RegisterMessage(DaskWorkerGroup)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/plugins/kubeflow/common.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/plugins/kubeflow/common.proto',
  package='flyteidl.plugins.kubeflow',
  syntax='proto3',
  serialized_options=_b('Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/plugins'),
  serialized_pb=_b('\n&flyteidl/plugins/kubeflow/common.proto\x12\x19\x66lyteidl.plugins.kubeflow\"\xac\x01\n\tRunPolicy\x12\x43\n\x10\x63lean_pod_policy\x18\x01 \x01(\x0e\x32).flyteidl.plugins.kubeflow.CleanPodPolicy\x12\"\n\x1attl_seconds_after_finished\x18\x02 \x01(\x05\x12\x1f\n\x17\x61\x63tive_deadline_seconds\x18\x03 \x01(\x05\x12\x15\n\rbackoff_limit\x18\x04 \x01(\x05*c\n\rRestartPolicy\x12\x18\n\x14RESTART_POLICY_NEVER\x10\x00\x12\x1d\n\x19RESTART_POLICY_ON_FAILURE\x10\x01\x12\x19\n\x15RESTART_POLICY_ALWAYS\x10\x02*`\n\x0e\x43leanPodPolicy\x12\x18\n\x14\x43LEANPOD_POLICY_NONE\x10\x00\x12\x1b\n\x17\x43LEANPOD_POLICY_RUNNING\x10\x01\x12\x17\n\x13\x43LEANPOD_POLICY_ALL\x10\x02\x42\x39Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/pluginsb\x06proto3')
)

_RESTARTPOLICY = _descriptor.EnumDescriptor(
  name='RestartPolicy',
  full_name='flyteidl.plugins.kubeflow.RestartPolicy',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESTART_POLICY_NEVER', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESTART_POLICY_ON_FAILURE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESTART_POLICY_ALWAYS', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=244,
  serialized_end=343,
)
_sym_db.RegisterEnumDescriptor(_RESTARTPOLICY)

RestartPolicy = enum_type_wrapper.EnumTypeWrapper(_RESTARTPOLICY)
_CLEANPODPOLICY = _descriptor.EnumDescriptor(
  name='CleanPodPolicy',
  full_name='flyteidl.plugins.kubeflow.CleanPodPolicy',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CLEANPOD_POLICY_NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLEANPOD_POLICY_RUNNING', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLEANPOD_POLICY_ALL', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=345,
  serialized_end=441,
)
_sym_db.RegisterEnumDescriptor(_CLEANPODPOLICY)

CleanPodPolicy = enum_type_wrapper.EnumTypeWrapper(_CLEANPODPOLICY)
RESTART_POLICY_NEVER = 0
RESTART_POLICY_ON_FAILURE = 1
RESTART_POLICY_ALWAYS = 2
CLEANPOD_POLICY_NONE = 0
CLEANPOD_POLICY_RUNNING = 1
CLEANPOD_POLICY_ALL = 2



_RUNPOLICY = _descriptor.Descriptor(
  name='RunPolicy',
  full_name='flyteidl.plugins.kubeflow.RunPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='clean_pod_policy', full_name='flyteidl.plugins.kubeflow.RunPolicy.clean_pod_policy', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ttl_seconds_after_finished', full_name='flyteidl.plugins.kubeflow.RunPolicy.ttl_seconds_after_finished', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='active_deadline_seconds', full_name='flyteidl.plugins.kubeflow.RunPolicy.active_deadline_seconds', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='backoff_limit', full_name='flyteidl.plugins.kubeflow.RunPolicy.backoff_limit', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=242,
)

_RUNPOLICY.fields_by_name['clean_pod_policy'].enum_type = _CLEANPODPOLICY
DESCRIPTOR.message_types_by_name['RunPolicy'] = _RUNPOLICY
DESCRIPTOR.enum_types_by_name['RestartPolicy'] = _RESTARTPOLICY
DESCRIPTOR.enum_types_by_name['CleanPodPolicy'] = _CLEANPODPOLICY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RunPolicy = _reflection.GeneratedProtocolMessageType('RunPolicy', (_message.Message,), dict(
  DESCRIPTOR = _RUNPOLICY,
  __module__ = 'flyteidl.plugins.kubeflow.common_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.kubeflow.RunPolicy)
  ))
_sym_db.RegisterMessage(RunPolicy)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
